==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Combo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ComboDir_$type } from "./ComboDir";
import { GroupingDirection_$type } from "./GroupingDirection";
import { FilteringOptions } from "./FilteringOptions";
import { ComboChangeEventArgs } from "./ComboChangeEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Combo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Combo, _super);
    function Combo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.n = new WCNativeHelper();
        _this.z = null;
        _this.change = null;
        _this.focus = null;
        _this.blur = null;
        _this.opening = null;
        _this.opened = null;
        _this.closing = null;
        _this.closed = null;
        _this.ac = null;
        _this.ab = null;
        return _this;
    }
    Object.defineProperty(Combo.prototype, "o", {
        get: function () {
            return this.n;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "nativeElement", {
        get: function () {
            return this.z;
        },
        set: function (a) {
            this.z = a;
            this.n.n = this.z;
        },
        enumerable: false,
        configurable: true
    });
    Combo.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Combo.prototype, "a", {
        get: function () {
            var ret_ = this.o.m("data");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("data", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ag", {
        get: function () {
            var ret_ = this.o.m("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "s", {
        get: function () {
            var ret_ = this.o.m("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "x", {
        get: function () {
            var ret_ = this.o.m("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "u", {
        get: function () {
            var ret_ = this.o.m("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "w", {
        get: function () {
            var ret_ = this.o.m("outlined");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("outlined", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "y", {
        get: function () {
            var ret_ = this.o.m("singleSelect");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("singleSelect", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "p", {
        get: function () {
            var ret_ = this.o.m("autofocus");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("autofocus", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "q", {
        get: function () {
            var ret_ = this.o.m("autofocusList");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("autofocusList", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "af", {
        get: function () {
            var ret_ = this.o.m("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ah", {
        get: function () {
            var ret_ = this.o.m("placeholder");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("placeholder", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ai", {
        get: function () {
            var ret_ = this.o.m("placeholderSearch");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("placeholderSearch", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "e", {
        get: function () {
            var ret_ = this.o.m("dir");
            ret_ = enumGetBox(ComboDir_$type, EnumUtil.getEnumValue(ComboDir_$type, this.o.f(ComboDir_$type, ret_)));
            return EnumUtil.getEnumValue(ComboDir_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ComboDir_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.o.u("dir", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "v", {
        get: function () {
            var ret_ = this.o.m("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "aj", {
        get: function () {
            var ret_ = this.o.m("valueKey");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("valueKey", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ad", {
        get: function () {
            var ret_ = this.o.m("displayKey");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("displayKey", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ae", {
        get: function () {
            var ret_ = this.o.m("groupKey");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("groupKey", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "g", {
        get: function () {
            var ret_ = this.o.m("groupSorting");
            ret_ = enumGetBox(GroupingDirection_$type, EnumUtil.getEnumValue(GroupingDirection_$type, this.o.f(GroupingDirection_$type, ret_)));
            return EnumUtil.getEnumValue(GroupingDirection_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(GroupingDirection_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.o.u("groupSorting", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "f", {
        get: function () {
            var ret_ = this.o.l("filteringOptions", function (a) { return new FilteringOptions(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("filteringOptions", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "r", {
        get: function () {
            var ret_ = this.o.m("caseSensitiveIcon");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("caseSensitiveIcon", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "t", {
        get: function () {
            var ret_ = this.o.m("disableFiltering");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("disableFiltering", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "c", {
        get: function () {
            var ret_ = this.o.m("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.o.u("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "b", {
        get: function () {
            var ret_ = this.o.m("selection");
            return ret_;
        },
        enumerable: false,
        configurable: true
    });
    Combo.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.o.q("change", function (a) { return _this.change(_this, ComboChangeEventArgs.a(a)); });
        }
        else {
            this.o.t("change");
        }
    };
    Combo.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.o.q("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.o.t("focus");
        }
    };
    Combo.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.o.q("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.o.t("blur");
        }
    };
    Combo.prototype.openingChanged = function () {
        var _this = this;
        if (this.opening != null) {
            this.o.q("opening", function (a) { return _this.opening(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.o.t("opening");
        }
    };
    Combo.prototype.openedChanged = function () {
        var _this = this;
        if (this.opened != null) {
            this.o.q("opened", function (a) { return _this.opened(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.o.t("opened");
        }
    };
    Combo.prototype.closingChanged = function () {
        var _this = this;
        if (this.closing != null) {
            this.o.q("closing", function (a) { return _this.closing(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.o.t("closing");
        }
    };
    Combo.prototype.closedChanged = function () {
        var _this = this;
        if (this.closed != null) {
            this.o.q("closed", function (a) { return _this.closed(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.o.t("closed");
        }
    };
    Combo.prototype.aw = function () {
        this.nativeElement.reportValidity();
    };
    Combo.prototype.an = function () {
        this.nativeElement.checkValidity();
    };
    Combo.prototype.as = function (a) {
        this.nativeElement.focus(this.o.h(a));
    };
    Combo.prototype.al = function () {
        this.nativeElement.blur();
    };
    Combo.prototype.ax = function (a) {
        this.nativeElement.select(this.o.h(a));
    };
    Combo.prototype.aq = function (a) {
        this.nativeElement.deselect(this.o.h(a));
    };
    Combo.prototype.az = function () {
        this.nativeElement.show();
    };
    Combo.prototype.at = function () {
        this.nativeElement.hide();
    };
    Combo.prototype.a0 = function () {
        this.nativeElement.toggle();
    };
    Combo.$t = markType(Combo, 'Combo', BaseElement.$);
    return Combo;
}(BaseElement));
export { Combo };

==> igniteui-react-18.5.2-beta.0.tgz: package/esm5/lib/Combo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { GroupingDirection_$type } from "./GroupingDirection";
import { FilteringOptions } from "./FilteringOptions";
import { ComboChangeEventArgs } from "./ComboChangeEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Combo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Combo, _super);
    function Combo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.m = new WCNativeHelper();
        _this.y = null;
        _this.change = null;
        _this.focus = null;
        _this.blur = null;
        _this.opening = null;
        _this.opened = null;
        _this.closing = null;
        _this.closed = null;
        _this.ab = null;
        _this.aa = null;
        return _this;
    }
    Object.defineProperty(Combo.prototype, "n", {
        get: function () {
            return this.m;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "nativeElement", {
        get: function () {
            return this.y;
        },
        set: function (a) {
            this.y = a;
            this.m.o = this.y;
        },
        enumerable: false,
        configurable: true
    });
    Combo.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Combo.prototype, "a", {
        get: function () {
            var ret_ = this.n.n("data");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("data", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "v", {
        get: function () {
            var ret_ = this.n.n("outlined");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("outlined", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "x", {
        get: function () {
            var ret_ = this.n.n("singleSelect");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("singleSelect", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "o", {
        get: function () {
            var ret_ = this.n.n("autofocus");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("autofocus", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "p", {
        get: function () {
            var ret_ = this.n.n("autofocusList");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("autofocusList", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ae", {
        get: function () {
            var ret_ = this.n.n("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "af", {
        get: function () {
            var ret_ = this.n.n("placeholder");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("placeholder", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ag", {
        get: function () {
            var ret_ = this.n.n("placeholderSearch");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("placeholderSearch", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "u", {
        get: function () {
            var ret_ = this.n.n("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ah", {
        get: function () {
            var ret_ = this.n.n("valueKey");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("valueKey", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ac", {
        get: function () {
            var ret_ = this.n.n("displayKey");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("displayKey", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "ad", {
        get: function () {
            var ret_ = this.n.n("groupKey");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("groupKey", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "f", {
        get: function () {
            var ret_ = this.n.n("groupSorting");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(GroupingDirection_$type, EnumUtil.getEnumValue(GroupingDirection_$type, this.n.f(GroupingDirection_$type, ret_)));
            return EnumUtil.getEnumValue(GroupingDirection_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(GroupingDirection_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.n.v("groupSorting", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "e", {
        get: function () {
            var ret_ = this.n.m("filteringOptions", function (a) { return new FilteringOptions(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("filteringOptions", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "q", {
        get: function () {
            var ret_ = this.n.n("caseSensitiveIcon");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("caseSensitiveIcon", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "s", {
        get: function () {
            var ret_ = this.n.n("disableFiltering");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("disableFiltering", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "c", {
        get: function () {
            var ret_ = this.n.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "b", {
        get: function () {
            var ret_ = this.n.n("selection");
            return ret_;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "r", {
        get: function () {
            var ret_ = this.n.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "w", {
        get: function () {
            var ret_ = this.n.n("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Combo.prototype, "t", {
        get: function () {
            var ret_ = this.n.n("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.n.v("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Combo.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.n.r("change", function (a) { return _this.change(_this, ComboChangeEventArgs.a(a)); });
        }
        else {
            this.n.u("change");
        }
    };
    Combo.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.n.r("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.n.u("focus");
        }
    };
    Combo.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.n.r("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.n.u("blur");
        }
    };
    Combo.prototype.openingChanged = function () {
        var _this = this;
        if (this.opening != null) {
            this.n.r("opening", function (a) { return _this.opening(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.n.u("opening");
        }
    };
    Combo.prototype.openedChanged = function () {
        var _this = this;
        if (this.opened != null) {
            this.n.r("opened", function (a) { return _this.opened(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.n.u("opened");
        }
    };
    Combo.prototype.closingChanged = function () {
        var _this = this;
        if (this.closing != null) {
            this.n.r("closing", function (a) { return _this.closing(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.n.u("closing");
        }
    };
    Combo.prototype.closedChanged = function () {
        var _this = this;
        if (this.closed != null) {
            this.n.r("closed", function (a) { return _this.closed(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.n.u("closed");
        }
    };
    Combo.prototype.ao = function () {
        this.nativeElement.connectedCallback();
    };
    Combo.prototype.ar = function (a) {
        this.nativeElement.focus(this.n.i(a));
    };
    Combo.prototype.aj = function () {
        this.nativeElement.blur();
    };
    Combo.prototype.aw = function (a) {
        this.nativeElement.select(this.n.i(a));
    };
    Combo.prototype.ap = function (a) {
        this.nativeElement.deselect(this.n.i(a));
    };
    Combo.prototype.az = function () {
        this.nativeElement.show();
    };
    Combo.prototype.as = function () {
        this.nativeElement.hide();
    };
    Combo.prototype.a0 = function () {
        this.nativeElement.toggle();
    };
    Combo.prototype.av = function () {
        this.nativeElement.reportValidity();
    };
    Combo.prototype.al = function () {
        this.nativeElement.checkValidity();
    };
    Combo.prototype.ax = function (a) {
        this.nativeElement.setCustomValidity(this.n.i(a));
    };
    Combo.$t = markType(Combo, 'Combo', BaseElement.$);
    return Combo;
}(BaseElement));
export { Combo };
